Range

Struct Range 

#[repr(C)]
pub(crate) struct Range { abstract_range: AbstractRange, associated_selections: DomRefCell<Vec<Dom<Selection>>>, }

Fields

abstract_range: AbstractRangeassociated_selections: DomRefCell<Vec<Dom<Selection>>>

Implementations

Source

impl Range

Source

impl Range

fn is_effectively_contained_node(&self, node: &Node) -> bool

fn ancestor_for_effectively_contained(&self) -> DomRoot<Node>

The definition of “effectively contained” contains the recursion of ancestors of a single fully selected text node. That is to say, that if the selection is a fully selected text node

[foobar]
, then the div would also be considered effectively contained. As such, we can’t use the common ancestor container, since that would be the text node only.

Instead, we traverse all the way up to the editing host, which we know is sufficient to know to include all contained nodes. That way, we also would traverse ancestors such as the parent div.

pub(crate) fn first_formattable_contained_node(&self) -> Option<DomRoot<Node>>

pub(crate) fn for_each_effectively_contained_child<Callback: FnMut(&Node)>( &self, callback: Callback, )

pub(crate) fn block_extend( &self, cx: &mut JSContext, document: &Document, ) -> DomRoot<Range>

pub(crate) fn record_current_states_and_values( &self, cx: &mut JSContext, ) -> Vec<RecordedStateOfCommand>

pub(crate) fn restore_states_and_values( &self, cx: &mut JSContext, selection: &Selection, context_object: &Document, overrides: Vec<RecordedStateOfCommand>, )

Source

impl Range

fn new_inherited( start_container: &Node, start_offset: u32, end_container: &Node, end_offset: u32, ) -> Range

pub(crate) fn new_with_doc( document: &Document, proto: Option<HandleObject<'_>>, can_gc: CanGc, ) -> DomRoot<Range>

pub(crate) fn new( document: &Document, start_container: &Node, start_offset: u32, end_container: &Node, end_offset: u32, can_gc: CanGc, ) -> DomRoot<Range>

fn new_with_proto( document: &Document, proto: Option<HandleObject<'_>>, start_container: &Node, start_offset: u32, end_container: &Node, end_offset: u32, can_gc: CanGc, ) -> DomRoot<Range>

pub(crate) fn contains(&self, node: &Node) -> bool

fn partially_contains(&self, node: &Node) -> bool

pub(crate) fn contained_children(&self) -> Fallible<ContainedChildren>

pub(crate) fn set_start(&self, node: &Node, offset: u32)

pub(crate) fn set_end(&self, node: &Node, offset: u32)

fn compare_point(&self, node: &Node, offset: u32) -> Fallible<Ordering>

pub(crate) fn associate_selection(&self, selection: &Selection)

pub(crate) fn disassociate_selection(&self, selection: &Selection)

fn report_change(&self)

fn abstract_range(&self) -> &AbstractRange

fn start(&self) -> &BoundaryPoint

fn end(&self) -> &BoundaryPoint

pub(crate) fn start_container(&self) -> DomRoot<Node>

pub(crate) fn start_offset(&self) -> u32

pub(crate) fn end_container(&self) -> DomRoot<Node>

pub(crate) fn end_offset(&self) -> u32

pub(crate) fn collapsed(&self) -> bool

fn client_rects(&self) -> impl Iterator<Item = Rect<Au, CSSPixel>>

fn set_the_start_or_end( &self, node: &Node, offset: u32, start_or_end: StartOrEnd, ) -> ErrorResult